@@ -1,3 +1,9 @@
+if ($#ARGV != 1) {
+    printf("Incorrect args: %d\n", $#ARGV);
+    die;
+}
+
+my $makejobs=2;
 my $repo = "https://qgvdial.googlecode.com/svn/trunk";
 my $cmd;
 
@@ -27,7 +33,7 @@ chomp $basedir;
 $basedir = "$basedir/qgvdial-$qver";
 
 # Delete any previous checkout directories
-system("rm -rf qgvdial-* qgvtp-* qgvdial_* qgvtp_* qgvdial*.bar");
+system("rm -rf tmp.sh qgvdial-* qgvtp-* qgvdial_* qgvtp_* qgvdial*.bar");
 
 $cmd = "svn export $repo qgvdial-$qver";
 system($cmd);
@@ -46,25 +52,39 @@ $cmd = "perl version.pl __THIS_IS_MY_EXTREMELY_LONG_KEY_ '$cipher' $basedir";
 print "$cmd\n";
 system($cmd);
 
+# __QT5_BB10__ replacement
+my $rep = $ARGV[1];
+$rep =~ s/\//\\\//g;
+print($rep);
+$cmd = "perl version.pl __QT5_BB10__ '$rep' $basedir";
+print "$cmd\n";
+system($cmd);
+
 # Copy the client secret file to the api directory
 $cmd = "cd $basedir/api ; cp ../../client_secret_284024172505-2go4p60orvjs7hdmcqpbblh4pr5thu79.apps.googleusercontent.com.json .";
 print "$cmd\n";
 system($cmd);
 
 # Prepare the bar-descriptor
-$cmd = "cd $basedir/qgvdial/bb10-qml ; mv bar-descriptor-deploy.xml bar-descriptor.xml";
+$cmd = "cd $basedir/qgvdial/bb10-qt5 ; mv bar-descriptor-deploy.xml bar-descriptor.xml";
 print "$cmd\n";
 system($cmd);
 
-$cmd = "cd $basedir/qgvdial/bb10-qml ; qmake ; make -j4";
+system("rm -f tmp.sh ; echo '#!/bin/bash' > tmp.sh ; echo source $ARGV[0] qt5 arm >> tmp.sh ; echo 'cd $basedir/qgvdial/bb10-qt5 ; qmake ; make -j$makejobs ; ntoarmv7-strip qgvdial' >> tmp.sh");
+$cmd = "chmod +x tmp.sh ; cat tmp.sh ; ./tmp.sh ; rm tmp.sh";
 print "$cmd\n";
 system($cmd);
 
-$cmd = "cd $basedir/qgvdial/bb10-qml ; blackberry-nativepackager -package qgvdial_$qver.bar bar-descriptor.xml ; cp qgvdial_$qver.bar ../../..";
+system("rm -f tmp.sh ; echo '#!/bin/bash' > tmp.sh ; echo source $ARGV[0] qt4 arm >> tmp.sh ; echo 'cd $basedir/qgvdial/bb10-qt5/qt4srv ; qmake ; make -j$makejobs ; ntoarmv7-strip qt4srv' >> tmp.sh");
+$cmd = "chmod +x tmp.sh ; cat tmp.sh ; ./tmp.sh ; rm tmp.sh";
 print "$cmd\n";
 system($cmd);
 
-$cmd = "cd $basedir ; mkdir -p bundle/qgvdial_10.1.0.4200 ; mv ../qgvdial_$qver.bar bundle/qgvdial_10.1.0.4200 ; cp build-files/qgvdial/bb10/release.xml bundle ; mv bundle ..";
+system("rm -f tmp.sh ; echo '#!/bin/bash' > tmp.sh ; echo source $ARGV[0] qt5 arm >> tmp.sh ; echo 'cd $basedir/qgvdial/bb10-qt5 ; blackberry-nativepackager -package qgvdial_$qver.bar bar-descriptor.xml' >> tmp.sh");
+$cmd = "chmod +x tmp.sh ; cat tmp.sh ; ./tmp.sh ; rm tmp.sh";
 print "$cmd\n";
 system($cmd);
 
+$cmd = "cd $basedir/qgvdial/bb10-qt5 ; cp qgvdial_$qver.bar ../../..";
+print "$cmd\n";
+system($cmd);
