@@ -2,6 +2,7 @@
 #define NOTIFYGVCONTACTSTABLE_H
 
 #include "global.h"
+#include "GContactsApi.h"
 
 class GVContactsTable : public QObject
 {
@@ -11,13 +12,10 @@ public:
     GVContactsTable (QObject *parent = 0);
     ~GVContactsTable ();
 
-    //! Use this to set the username and password for the contacts API login
-    void setUserPass (const QString &strU, const QString &strP);
-
     //! Use this to login
-    void loginSuccess ();
+    void login (const QString &strU, const QString &strP);
     //! Use this to logout
-    void loggedOut ();
+    void logout ();
 
 signals:
     //! Status emitter for status bar
@@ -30,46 +28,26 @@ public slots:
     void refreshContacts ();
 
 private slots:
-    //! Invoked on response to login to contacts API
-    void onLoginResponse (QNetworkReply *reply);
+    void onPresentCaptcha(AsyncTaskToken *task, const QString &captchaUrl);
+    void onLoginDone();
 
-    // Invoked when the google contacts API responds with the contacts
-    void onGotContacts (QNetworkReply *reply);
     // Invoked when one contact is parsed out of the XML
-    void gotOneContact (const ContactInfo &contactInfo);
+    void gotOneContact (ContactInfo contactInfo);
     //! Invoked when all the contacts are parsed
-    void onContactsParsed(bool rv);
+    void onContactsParsed();
 
 private:
-    QNetworkReply *
-    postRequest (QString         strUrl,
-                 QStringPairList arrPairs,
-                 QObject        *receiver,
-                 const char     *method);
-    QNetworkReply *
-    getRequest (QString         strUrl,
-                QObject        *receiver,
-                const char     *method);
+    GContactsApi    api;
 
-
-private:
     //! Last updated
     QDateTime dtUpdate;
 
     //! Username and password for google authentication
     QString         strUser, strPass;
-    //! The authentication string returned by the contacts API
-    QString         strGoogleAuth;
-
-    //! The network manager for contacts API
-    QNetworkAccessManager nwMgr;
 
     //! Mutex protecting the following variable
     QMutex          mutex;
 
-    //! Is the user logged in?
-    bool            bLoggedIn;
-
     //! Refresh requested but waiting for login
     bool            bRefreshRequested;
 
