@@ -20,12 +20,19 @@ Contact: yuvraaj@gmail.com
 */
 
 #include "BBPhoneAccount.h"
+
+#if QT_VERSION < QT_VERSION_CHECK(5,0,0)
 #include <bb/system/phone/Line>
 #include <bb/system/phone/LineType>
+#else
+#include <QDesktopServices>
+#endif
 
 BBPhoneAccount::BBPhoneAccount(QObject *parent)
 : IPhoneAccount(parent)
+#if QT_VERSION < QT_VERSION_CHECK(5,0,0)
 , m_phone(this)
+#endif
 {
 }//BBPhoneAccount::BBPhoneAccount
 
@@ -56,7 +63,11 @@ BBPhoneAccount::initiateCall(AsyncTaskToken *task)
     }
 
     QString dest = task->inParams["destination"].toString();
+#if QT_VERSION < QT_VERSION_CHECK(5,0,0)
     m_phone.initiateCellularCall(dest);
+#else
+    QDesktopServices::openUrl (QString("tel:%1").arg (dest));
+#endif
     Q_DEBUG(QString("Call initiated to dest: %1").arg(dest));
 
     //TODO: Do this in the slot for the completion of the phone call
@@ -68,12 +79,14 @@ BBPhoneAccount::initiateCall(AsyncTaskToken *task)
 QString
 BBPhoneAccount::getNumber()
 {
+#if QT_VERSION < QT_VERSION_CHECK(5,0,0)
     QMap <QString, bb::system::phone::Line> l = m_phone.lines();
     foreach (QString key, l.keys()) {
         if (l[key].type() == bb::system::phone::LineType::Cellular) {
             return l[key].address();
         }
     }
+#endif
 
     return "";
 }//BBPhoneAccount::getNumber
