@@ -29,6 +29,7 @@ class ContactsModel;
 class InboxModel;
 
 class CacheDbPrivate;
+class O2ContactsStore;
 class CacheDb : public QObject
 {
     Q_OBJECT
@@ -40,6 +41,8 @@ public:
     bool init(const QString &dbDir);
     void deinit();
 
+    O2ContactsStore *createContactsStore();
+
     void setQuickAndDirty(bool beDirty = true);
 
     bool usernameIsCached();
@@ -51,14 +54,6 @@ public:
     bool loadCookies(QList<QNetworkCookie> &cookies);
     bool clearCookies();
 
-    void setTFAFlag(bool set);
-    bool getTFAFlag();
-    void clearTFAFlag();
-
-    bool getAppPass(QString &strPass);
-    bool setAppPass(const QString &strPass);
-    void clearAppPass();
-
     bool putTempFile(const QString &strLink, const QString &strPath);
     bool getTempFile(const QString &strLink, QString &strPath) const;
     bool clearTempFileByLink(const QString &strLink, bool deleteFile);
