@@ -31,7 +31,7 @@ Contact: yuvraaj@gmail.com
 #include <openssl/aes.h>
 #include <openssl/evp.h>
 
-#if defined(Q_OS_SYMBIAN) || defined(Q_WS_MAEMO_5)
+#if defined(Q_OS_SYMBIAN) || defined(Q_WS_MAEMO_5) || defined(Q_OS_BLACKBERRY)
 #define SYSTEMDISPLAYINFO 0
 #else
 #include <QtSystemInfo/QSystemDisplayInfo>
@@ -82,7 +82,11 @@ public:
     void setLongWork (QWidget *window, bool bSet = false);
 
     QRect getStartingSize ();
-    QString getAppDirectory ();
+
+    QString getLogDirectory ();
+    QString getDbDirectory ();
+    QString getTmpDirectory ();
+
     QString getMainQML();
     void getMultipliers(double &hMul, double &wMul, double &fontMul);
 
@@ -117,6 +121,9 @@ signals:
     void sigQuit();
 ////////////////////////////////////////////////////////////////////////////////
 
+private:
+    QString getAppDirectory ();
+
 private:
     OsDependent(QObject *parent = 0);
 
