@@ -1,6 +1,6 @@
 /*
 qgvdial is a cross platform Google Voice Dialer
-Copyright (C) 2009-2012  Yuvraaj Kelkar
+Copyright (C) 2009-2013  Yuvraaj Kelkar
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
@@ -23,6 +23,7 @@ Contact: yuvraaj@gmail.com
 
 static CacheDatabase *dbMain = NULL;
 static NwInfo *nwInfo = NULL;
+static IPhoneIntegration *phoneIntegration = NULL;
 
 Singletons::Singletons (QObject *parent/* = 0*/)
 : QObject (parent)
@@ -87,6 +88,17 @@ Singletons::getNwInfo ()
     return (*nwInfo);
 }//Singletons::getNwInfo
 
+IPhoneIntegration &
+Singletons::getPhoneIntegration ()
+{
+    if (NULL == phoneIntegration) {
+        OsDependent &osd = Singletons::getRef().getOSD();
+        phoneIntegration = osd.createPhoneIntegreationObj (this);
+    }
+
+    return (*phoneIntegration);
+}//Singletons::getPhoneIntegration
+
 void
 Singletons::deinit()
 {
